@@ -73,7 +73,7 @@ Caveats
 
 Upgrading
 ---------
-During the current development cycle, programmatic access to the definition and graph caches might become unstable. If 
+During the current development cycle, programmatic access to the definition and graph caches might become unstable. If
 you have any problems working with the database, try removing it with one of the following commands:
 
 1. Running :code:`pybel manage drop` (unix)
@@ -83,7 +83,7 @@ you have any problems working with the database, try removing it with one of the
 PyBEL will build a new database and populate it on the next run.
 """
 
-from . import canonicalize, constants, examples, examples, io, struct
+from . import canonicalize, constants, examples, io, struct
 from .canonicalize import *
 from .examples import *
 from .io import *
@@ -94,24 +94,12 @@ from .struct import *
 from .utils import get_version
 
 __all__ = (
-        struct.__all__ +
-        io.__all__ +
-        canonicalize.__all__ +
-        database_io.__all__ +
-        cache_manager.__all__ +
-        examples.__all__ + [
-            'get_version',
-        ]
+    struct.__all__ +
+    io.__all__ +
+    canonicalize.__all__ +
+    database_io.__all__ +
+    cache_manager.__all__ +
+    examples.__all__ + [
+        'get_version',
+    ]
 )
-
-__version__ = '0.12.1'
-
-__title__ = 'PyBEL'
-__description__ = 'Parsing, validation, compilation, and data exchange of Biological Expression Language (BEL)'
-__url__ = 'https://github.com/pybel/pybel'
-
-__author__ = 'Charles Tapley Hoyt'
-__email__ = 'charles.hoyt@scai.fraunhofer.de'
-
-__license__ = 'Apache 2.0 License'
-__copyright__ = 'Copyright (c) 2016-2018 Charles Tapley Hoyt'
