@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 
-"""
-Entrypoint module, in case you use `python -m pybel`
+"""Entrypoint module, in case you use `python -m pybel`.
 
 Why does this file exist, and why __main__? For more info, read:
 
