@@ -16,10 +16,10 @@ from os import environ, makedirs, mkdir, path
 
 log = getLogger(__name__)
 
-VERSION = '0.12.1'
+VERSION = '0.13.1'
 
 #: The last PyBEL version where the graph data definition changed
-PYBEL_MINIMUM_IMPORT_VERSION = 0, 12, 0
+PYBEL_MINIMUM_IMPORT_VERSION = 0, 13, 0
 
 BELFRAMEWORK_DOMAIN = 'http://resource.belframework.org'
 OPENBEL_DOMAIN = 'http://resources.openbel.org'
@@ -52,6 +52,8 @@ DEFAULT_CACHE_LOCATION = path.join(PYBEL_DIR, DEFAULT_CACHE_NAME)
 #: The default cache connection string uses sqlite.
 DEFAULT_CACHE_CONNECTION = 'sqlite:///' + DEFAULT_CACHE_LOCATION
 
+_BASE_CONFIG_DIR = path.join(path.expanduser('~'), '.config')
+
 
 def get_config_dir():
     """Return the path to the directory where configuration is stored for PyBEL.
@@ -60,7 +62,9 @@ def get_config_dir():
 
     :rtype: str
     """
-    return environ.get('PYBEL_CONFIG_DIRECTORY', path.join(path.expanduser('~'), '.config', 'pybel'))
+    if VERSION.endswith('-dev'):
+        return environ.get('PYBEL_DEV_CONFIG_DIRECTORY', path.join(_BASE_CONFIG_DIR, 'pybel-dev'))
+    return environ.get('PYBEL_CONFIG_DIRECTORY', path.join(_BASE_CONFIG_DIR, 'pybel'))
 
 
 _config_dir = get_config_dir()
@@ -516,6 +520,7 @@ GRAPH_ANNOTATION_LIST = 'annotation_list'
 GRAPH_WARNINGS = 'warnings'
 GRAPH_PYBEL_VERSION = 'pybel_version'
 GRAPH_UNCACHED_NAMESPACES = 'namespaces_uncached'
+GRAPH_PATH = 'path'
 
 #: The key for the document name. Can be accessed by :code:`graph.document[METADATA_NAME]` or by using the property
 #: built into the :class:`pybel.BELGraph` class, :func:`pybel.BELGraph.name`
