@@ -2,12 +2,10 @@
 
 """Classes for DSL nodes."""
 
-import abc
 import hashlib
+from abc import ABCMeta, abstractmethod
 from operator import methodcaller
 
-import six
-
 from .exc import InferCentralDogmaException, PyBELDSLException
 from .utils import entity
 from ..constants import (
@@ -68,8 +66,7 @@ __all__ = [
 _as_bel = methodcaller('as_bel')
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BaseEntity(dict):
+class BaseEntity(dict, metaclass=ABCMeta):
     """This class represents all BEL nodes. It can be converted to a tuple and hashed."""
 
     def __init__(self, func):
@@ -91,7 +88,7 @@ class BaseEntity(dict):
     def _func(self):
         return rev_abundance_labels[self.function]
 
-    @abc.abstractmethod
+    @abstractmethod
     def as_bel(self):
         """Return this entity as a BEL string.
 
@@ -107,7 +104,7 @@ class BaseEntity(dict):
 
     @property
     def sha512(self):
-        """The SHA512 hash of this node.
+        """Get the SHA512 hash of this node.
 
         :rtype: str
         """
@@ -318,8 +315,7 @@ class CentralDogma(BaseAbundance):
         )
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Variant(dict):
+class Variant(dict, metaclass=ABCMeta):
     """The superclass for variant dictionaries."""
 
     def __init__(self, kind):
@@ -329,7 +325,7 @@ class Variant(dict):
         """
         super(Variant, self).__init__({KIND: kind})
 
-    @abc.abstractmethod
+    @abstractmethod
     def as_bel(self):
         """Return this variant as a BEL string.
 
@@ -516,15 +512,20 @@ class Fragment(Variant):
         if description:
             self[FRAGMENT_DESCRIPTION] = description
 
+    @property
+    def range(self):
+        """Get the range of this fragment."""
+        if FRAGMENT_MISSING in self:
+            return '?'
+
+        return '{}_{}'.format(self[FRAGMENT_START], self[FRAGMENT_STOP])
+
     def as_bel(self):
         """Return this fragment variant as a BEL string.
 
         :rtype: str
         """
-        if FRAGMENT_MISSING in self:
-            res = '"?"'
-        else:
-            res = '"{}_{}"'.format(self[FRAGMENT_START], self[FRAGMENT_STOP])
+        res = '"{}"'.format(self.range)
 
         if FRAGMENT_DESCRIPTION in self:
             res += ', "{}"'.format(self[FRAGMENT_DESCRIPTION])
@@ -746,11 +747,13 @@ class ListAbundance(BaseEntity):
         :type members: BaseAbundance or list[BaseAbundance]
         """
         super(ListAbundance, self).__init__(func=func)
-        self[MEMBERS] = (
-            [members]
-            if isinstance(members, BaseEntity) else
-            sorted(members, key=_as_bel)
-        )
+
+        if isinstance(members, BaseEntity):
+            self[MEMBERS] = [members]
+        elif 0 == len(members):
+            raise ValueError('List abundance can not be instantiated with an empty members list.')
+        else:
+            self[MEMBERS] = sorted(members, key=_as_bel)
 
     @property
     def members(self):
@@ -821,11 +824,10 @@ class CompositeAbundance(ListAbundance):
         super(CompositeAbundance, self).__init__(func=COMPOSITE, members=members)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class FusionRangeBase(dict):
+class FusionRangeBase(dict, metaclass=ABCMeta):
     """The superclass for fusion range data dictionaries."""
 
-    @abc.abstractmethod
+    @abstractmethod
     def as_bel(self):
         """Return this fusion range as BEL.
 
@@ -908,7 +910,7 @@ class FusionBase(BaseEntity):
 
     @property
     def partner_5p(self):
-        """The 5' partner.
+        """Get the 5' partner.
 
         :rtype: CentralDogma
         """
@@ -916,7 +918,7 @@ class FusionBase(BaseEntity):
 
     @property
     def partner_3p(self):
-        """The 3' partner.
+        """Get the 3' partner.
 
         :rtype: CentralDogma
         """
@@ -924,7 +926,7 @@ class FusionBase(BaseEntity):
 
     @property
     def range_5p(self):
-        """The 5' partner's range.
+        """Get the 5' partner's range.
 
         :rtype: FusionRangeBase
         """
@@ -932,7 +934,7 @@ class FusionBase(BaseEntity):
 
     @property
     def range_3p(self):
-        """The 3' partner's range.
+        """Get the 3' partner's range.
 
         :rtype: FusionRangeBase
         """
