@@ -4,12 +4,13 @@
 
 import json
 import os
-from operator import itemgetter, methodcaller
-
 from itertools import chain, count
+from operator import methodcaller
+from typing import Any, Mapping, TextIO
 
 from .utils import ensure_version
-from ..constants import GRAPH_ANNOTATION_LIST, GRAPH_UNCACHED_NAMESPACES
+from ..constants import GRAPH_ANNOTATION_LIST, GRAPH_UNCACHED_NAMESPACES, MEMBERS, PRODUCTS, REACTANTS
+from ..dsl import BaseEntity
 from ..struct import BELGraph
 from ..tokens import parse_result_to_dsl
 
@@ -25,13 +26,8 @@ __all__ = [
 ]
 
 
-def to_json(graph):
-    """Convert this graph to a Node-Link JSON object.
-
-    :param BELGraph graph: A BEL graph
-    :return: A Node-Link JSON object representing the given graph
-    :rtype: dict
-    """
+def to_json(graph: BELGraph) -> Mapping[str, Any]:
+    """Convert this graph to a Node-Link JSON object."""
     graph_json_dict = node_link_data(graph)
 
     # Convert annotation list definitions (which are sets) to canonicalized/sorted lists
@@ -46,88 +42,52 @@ def to_json(graph):
     return graph_json_dict
 
 
-def to_json_path(graph, path, **kwargs):
-    """Write this graph to the given path as a Node-Link JSON.
-
-    :param BELGraph graph: A BEL graph
-    :param str path: A file path
-    """
+def to_json_path(graph: BELGraph, path: str, **kwargs) -> None:
+    """Write this graph to the given path as a Node-Link JSON."""
     with open(os.path.expanduser(path), 'w') as f:
-        return to_json_file(graph, file=f, **kwargs)
+        to_json_file(graph, file=f, **kwargs)
 
 
-def to_json_file(graph, file, **kwargs):
-    """Write this graph as Node-Link JSON to a file.
-
-    :param BELGraph graph: A BEL graph
-    :param file file: A write-supporting file or file-like object
-    """
+def to_json_file(graph: BELGraph, file: TextIO, **kwargs) -> None:
+    """Write this graph as Node-Link JSON to a file."""
     graph_json_dict = to_json(graph)
     json.dump(graph_json_dict, file, ensure_ascii=False, **kwargs)
 
 
-def to_jsons(graph, **kwargs):
-    """Dump this graph as a Node-Link JSON object to a string.
-
-    :param BELGraph graph: A BEL graph
-    :return: A string representation of the Node-Link JSON produced for this graph by :func:`pybel.to_json`
-    :rtype: str
-    """
+def to_jsons(graph: BELGraph, **kwargs) -> str:
+    """Dump this graph as a Node-Link JSON object to a string."""
     graph_json_str = to_json(graph)
     return json.dumps(graph_json_str, ensure_ascii=False, **kwargs)
 
 
-def from_json(graph_json_dict, check_version=True):
-    """Build a graph from Node-Link JSON Object.
-
-    :param dict graph_json_dict: A JSON dictionary representing a graph
-    :param bool check_version: Checks if the graph was produced by this version of PyBEL
-    :rtype: BELGraph
-    """
+def from_json(graph_json_dict: Mapping[str, Any], check_version=True) -> BELGraph:
+    """Build a graph from Node-Link JSON Object."""
     graph = node_link_graph(graph_json_dict)
     return ensure_version(graph, check_version=check_version)
 
 
-def from_json_path(path, check_version=True):
-    """Build a graph from a file containing Node-Link JSON.
-
-    :param str path: A file path. Expands user.
-    :param bool check_version: Checks if the graph was produced by this version of PyBEL
-    :rtype: BELGraph
-    """
+def from_json_path(path: str, check_version: bool = True) -> BELGraph:
+    """Build a graph from a file containing Node-Link JSON."""
     with open(os.path.expanduser(path)) as f:
         return from_json_file(f, check_version=check_version)
 
 
-def from_json_file(file, check_version=True):
-    """Build a graph from the Node-Link JSON contained in the given file.
-
-    :param file file: A readable file or file-like
-    :param bool check_version: Checks if the graph was produced by this version of PyBEL
-    :rtype: BELGraph
-    """
+def from_json_file(file: TextIO, check_version=True) -> BELGraph:
+    """Build a graph from the Node-Link JSON contained in the given file."""
     graph_json_dict = json.load(file)
     return from_json(graph_json_dict, check_version=check_version)
 
 
-def from_jsons(graph_json_str, check_version=True):
-    """Read a BEL graph from a Node-Link JSON string.
-
-    :param str graph_json_str: A Node-Link JSON string produced by PyBEL
-    :param bool check_version: Checks if the graph was produced by this version of PyBEL
-    :rtype: BELGraph
-    """
+def from_jsons(graph_json_str: str, check_version: bool = True) -> BELGraph:
+    """Read a BEL graph from a Node-Link JSON string."""
     graph_json_dict = json.loads(graph_json_str)
     return from_json(graph_json_dict, check_version=check_version)
 
 
-def node_link_data(graph):
+def node_link_data(graph: BELGraph) -> Mapping[str, Any]:
     """Convert a BEL graph to a node-link format.
 
     Adapted from :func:`networkx.readwrite.json_graph.node_link_data`
-
-    :param pybel.BELGraph graph:
-    :rtype: dict
     """
     nodes = sorted(graph, key=methodcaller('as_bel'))
 
@@ -136,14 +96,14 @@ def node_link_data(graph):
     return {
         'directed': True,
         'multigraph': True,
-        'graph': graph.graph,
+        'graph': graph.graph.copy(),
         'nodes': [
             _augment_node_with_sha512(node)
             for node in nodes
         ],
         'links': [
             dict(chain(
-                data.items(),
+                data.copy().items(),
                 [('source', mapping[u]), ('target', mapping[v]), ('key', key)]
             ))
             for u, v, key, data in graph.edges(keys=True, data=True)
@@ -151,27 +111,26 @@ def node_link_data(graph):
     }
 
 
-def _augment_node_with_sha512(node):
-    """
-
-    :type node: BaseEntity
-    :rtype: dict
-    """
-    v = node.copy()
-    v['id'] = node.as_sha512()
-    return v
+def _augment_node_with_sha512(node: BaseEntity) -> BaseEntity:
+    """Add the SHA-512 identifier to a node's dictionary."""
+    rv = node.copy()
+    rv['id'] = node.as_sha512()
+    for m in chain(node.get(MEMBERS, []), node.get(REACTANTS, []), node.get(PRODUCTS, [])):
+        m.update(_augment_node_with_sha512(m))
+    return rv
 
 
-def node_link_graph(data):
+def node_link_graph(data: Mapping[str, Any]) -> BELGraph:
     """Return graph from node-link data format.
 
     Adapted from :func:`networkx.readwrite.json_graph.node_link_graph`
-
-    :param dict data:
-    :rtype: BELGraph
     """
     graph = BELGraph()
     graph.graph = data.get('graph', {})
+    graph.graph[GRAPH_ANNOTATION_LIST] = {
+        keyword: set(values)
+        for keyword, values in graph.graph[GRAPH_ANNOTATION_LIST].items()
+    }
 
     mapping = []
 
@@ -181,18 +140,14 @@ def node_link_graph(data):
         mapping.append(node)
 
     for data in data['links']:
-        src = data['source']
-        tgt = data['target']
-        key = data['key']
+        u = mapping[data['source']]
+        v = mapping[data['target']]
 
-        u = mapping[src]
-        v = mapping[tgt]
-
-        edgedata = {
+        edge_data = {
             k: v
             for k, v in data.items()
             if k not in {'source', 'target', 'key'}
         }
-        graph.add_edge(u, v, key=key, **edgedata)
+        graph.add_edge(u, v, key=data['key'], **edge_data)
 
     return graph
