@@ -4,7 +4,9 @@
 
 import datetime
 import hashlib
+import json
 from collections import defaultdict
+from typing import Iterable, Set, Tuple
 
 from sqlalchemy import (
     Boolean, Column, Date, DateTime, ForeignKey, Integer, LargeBinary, String, Table, Text, UniqueConstraint,
@@ -14,18 +16,18 @@ from sqlalchemy.orm import backref, relationship
 
 from .utils import int_or_str
 from ..constants import (
-    ANNOTATIONS, BELNS_ENCODING_STR, CITATION, CITATION_AUTHORS, CITATION_DATE, CITATION_FIRST_AUTHOR,
+    CITATION, CITATION_AUTHORS, CITATION_DATE, CITATION_FIRST_AUTHOR,
     CITATION_LAST_AUTHOR, CITATION_NAME, CITATION_PAGES, CITATION_REFERENCE, CITATION_TITLE, CITATION_TYPE,
-    CITATION_TYPE_PUBMED, CITATION_VOLUME, COMPLEX, COMPOSITE, EFFECT, EVIDENCE, FRAGMENT, FUSION, GMOD, HAS_COMPONENT,
-    HAS_PRODUCT, HAS_REACTANT, HGVS, IDENTIFIER, LOCATION, METADATA_AUTHORS, METADATA_CONTACT, METADATA_COPYRIGHT,
-    METADATA_DESCRIPTION, METADATA_DISCLAIMER, METADATA_LICENSES, METADATA_NAME, METADATA_VERSION, MODIFIER, NAME,
-    NAMESPACE, OBJECT, PARTNER_3P, PARTNER_5P, PMOD, RANGE_3P, RANGE_5P, REACTION, RELATION, SUBJECT,
+    CITATION_TYPE_PUBMED, CITATION_VOLUME, EFFECT, EVIDENCE, FRAGMENT, FUSION, GMOD, HGVS, IDENTIFIER, LOCATION,
+    METADATA_AUTHORS, METADATA_CONTACT, METADATA_COPYRIGHT, METADATA_DESCRIPTION, METADATA_DISCLAIMER,
+    METADATA_LICENSES, METADATA_NAME, METADATA_VERSION, MODIFIER, NAME, NAMESPACE, OBJECT, PARTNER_3P, PARTNER_5P, PMOD,
+    RANGE_3P, RANGE_5P, SUBJECT,
 )
 from ..dsl import (
-    FUNC_TO_DSL, FUNC_TO_FUSION_DSL, complex_abundance, composite_abundance, fragment, fusion_range, gmod, hgvs,
-    missing_fusion_range, named_complex_abundance, pmod, reaction,
+    fragment, fusion_range, gmod, hgvs, missing_fusion_range, pmod,
 )
 from ..io.gpickle import from_bytes, to_bytes
+from ..tokens import parse_result_to_dsl
 
 __all__ = [
     'Base',
@@ -100,7 +102,7 @@ class Namespace(Base):
                      doc="Contains regex pattern for value identification.")
 
     miriam_id = Column(String(16), nullable=True,
-                       doc='MIRIAM resource identifier matching the regular expression ``^MIR:001\d{5}$``')
+                       doc=r'MIRIAM resource identifier matching the regular expression ``^MIR:001\d{5}$``')
     miriam_name = Column(String(255), nullable=True)
     miriam_namespace = Column(String(255), nullable=True)
     miriam_uri = Column(String(255), nullable=True)
@@ -133,30 +135,8 @@ class Namespace(Base):
     def __str__(self):
         return self.keyword
 
-    def get_entry_names(self):
-        """Get all entry names.
-
-        :rtype: set[str]
-        """
-        return {entry.name for entry in self.entries}
-
-    def to_values(self):
-        """Return this namespace as a dictionary of names to their encodings.
-
-        Encodings are represented as a string, and lookup operations take constant time O(8).
-
-        :rtype: dict[str,str]
-        """
-        return {
-            entry.name: entry.encoding if entry.encoding else BELNS_ENCODING_STR
-            for entry in self.entries
-        }
-
-    def to_tree_list(self):
-        """Returns an edge set of the tree represented by this namespace's hierarchy
-
-        :rtype: set[tuple[str,str]]
-        """
+    def to_tree_list(self) -> Set[Tuple[str, str]]:
+        """Return an edge set of the tree represented by this namespace's hierarchy."""
         return {
             (parent.name, child.name)
             for parent in self.entries
@@ -164,7 +144,7 @@ class Namespace(Base):
         }
 
     def to_json(self, include_id=False):
-        """Returns the most useful entries as a dictionary
+        """Return the most useful entries as a dictionary.
 
         :param bool include_id: If true, includes the model identifier
         :rtype: dict[str,str]
@@ -190,7 +170,6 @@ class NamespaceEntry(Base):
     """Represents a name within a BEL namespace."""
 
     __tablename__ = NAME_TABLE_NAME
-
     id = Column(Integer, primary_key=True)
 
     name = Column(String(1023), index=True, nullable=False,
@@ -266,7 +245,6 @@ class Network(Base):
     """Represents a collection of edges, specified by a BEL Script."""
 
     __tablename__ = NETWORK_TABLE_NAME
-
     id = Column(Integer, primary_key=True)
 
     name = Column(String(255), nullable=False, index=True, doc='Name of the given Network (from the BEL file)')
@@ -289,10 +267,10 @@ class Network(Base):
         UniqueConstraint(name, version),
     )
 
-    def to_json(self, include_id=False):
+    def to_json(self, include_id: bool = False):
         """Return this network as JSON.
 
-        :param bool include_id: If true, includes the model identifier
+        :param include_id: If true, includes the model identifier
         :rtype: dict[str,str]
         """
         result = {
@@ -327,27 +305,18 @@ class Network(Base):
         return result
 
     @classmethod
-    def name_contains(cls, name_query):
-        """Build a filter for networks whose names contain the query.
-
-        :param str name_query:
-        """
+    def name_contains(cls, name_query: str):
+        """Build a filter for networks whose names contain the query."""
         return cls.name.contains(name_query)
 
     @classmethod
-    def description_contains(cls, description_query):
-        """Build a filter for networks whose descriptions contain the query.
-
-        :param str description_query:
-        """
+    def description_contains(cls, description_query: str):
+        """Build a filter for networks whose descriptions contain the query."""
         return cls.description.contains(description_query)
 
     @classmethod
-    def id_in(cls, network_ids):
-        """Build a filter for networks whose identifiers appear in the given sequence.
-
-        :param iter[int] network_ids:
-        """
+    def id_in(cls, network_ids: Iterable[int]):
+        """Build a filter for networks whose identifiers appear in the given sequence."""
         return cls.id.in_(network_ids)
 
     def __repr__(self):
@@ -382,7 +351,6 @@ class Modification(Base):
     """The modifications that are present in the network are stored in this table."""
 
     __tablename__ = MODIFICATION_TABLE_NAME
-
     id = Column(Integer, primary_key=True)
 
     type = Column(String(255), nullable=False, doc='Type of the stored modification e.g. Fusion, gmod, pmod, etc')
@@ -484,7 +452,6 @@ class Node(Base):
     """Represents a BEL Term."""
 
     __tablename__ = NODE_TABLE_NAME
-
     id = Column(Integer, primary_key=True)
 
     type = Column(String(255), nullable=False, doc='The type of the represented biological entity e.g. Protein or Gene')
@@ -499,6 +466,22 @@ class Node(Base):
     modifications = relationship(Modification, secondary=node_modification, lazy='dynamic',
                                  backref=backref('nodes', lazy='dynamic'))
 
+    data = Column(Text, nullable=False, doc='PyBEL BaseEntity as JSON')
+
+    @staticmethod
+    def _start_from_base_entity(base_entity):
+        """Convert a base entity to a node model.
+
+        :type base_entity: pybel.dsl.BaseEntity
+        :rtype: Node
+        """
+        return Node(
+            type=base_entity.function,
+            bel=base_entity.as_bel(),
+            sha512=base_entity.sha512,
+            data=json.dumps(base_entity),
+        )
+
     @classmethod
     def bel_contains(cls, bel_query):
         """Build a filter for nodes whose BEL contain the query.
@@ -524,73 +507,10 @@ class Node(Base):
 
         :rtype: pybel.dsl.BaseEntity
         """
-        func = self.type
-
-        if self.has_fusion:
-            j = self.modifications[0].to_json()
-            fusion_dsl = FUNC_TO_FUSION_DSL[func]
-            member_dsl = FUNC_TO_DSL[func]
-            partner_5p = member_dsl(**j[PARTNER_5P])
-            partner_3p = member_dsl(**j[PARTNER_3P])
-
-            return fusion_dsl(
-                partner_5p=partner_5p,
-                partner_3p=partner_3p,
-                range_5p=j.get(RANGE_5P),
-                range_3p=j.get(RANGE_3P),
-            )
-
-        if func == REACTION:
-            return reaction(
-                reactants=self._get_list_by_relation(HAS_REACTANT),
-                products=self._get_list_by_relation(HAS_PRODUCT)
-            )
-
-        if func in {COMPLEX, COMPOSITE}:
-            members = self._get_list_by_relation(HAS_COMPONENT)
-
-            if self.type == COMPOSITE:
-                return composite_abundance(members)
-
-            if self.namespace_entry and members:
-                return complex_abundance(
-                    members=members,
-                    namespace=self.namespace_entry.namespace.keyword,
-                    name=self.namespace_entry.name,
-                    identifier=self.namespace_entry.identifier,
-                )
-            if self.namespace_entry and not members:
-                return named_complex_abundance(
-                    namespace=self.namespace_entry.namespace.keyword,
-                    name=self.namespace_entry.name,
-                    identifier=self.namespace_entry.identifier,
-                )
-
-            if members:
-                return complex_abundance(members=members)
-
-            raise ValueError('complex can not be nameless and have no members')
-
-        dsl = FUNC_TO_DSL[func]
-
-        if self.is_variant:
-            return dsl(
-                namespace=self.namespace_entry.namespace.keyword,
-                name=self.namespace_entry.name,
-                identifier=self.namespace_entry.identifier,
-                variants=[
-                    modification.to_json()
-                    for modification in self.modifications
-                ]
-            )
-
-        return dsl(
-            namespace=self.namespace_entry.namespace.keyword,
-            name=self.namespace_entry.name,
-            identifier=self.namespace_entry.identifier,
-        )
+        return parse_result_to_dsl(json.loads(self.data))
 
     def to_json(self):
+        """Serialize this node as a JSON object using as_bel()."""
         return self.as_bel()
 
 
@@ -642,7 +562,7 @@ class Author(Base):
 
     @classmethod
     def has_name_in(cls, names):
-        """Build a filter if the author has any of the given names"""
+        """Build a filter if the author has any of the given names."""
         return cls.sha512.in_({
             cls.hash_name(name)
             for name in names
@@ -875,6 +795,8 @@ class Edge(Base):
 
     sha512 = Column(String(255), index=True, doc='The hash of the source, target, and associated metadata')
 
+    data = Column(Text, nullable=False, doc='The stringified JSON representing this edge')
+
     def __str__(self):
         return self.bel
 
@@ -893,30 +815,6 @@ class Edge(Base):
 
         return dict(annotations) or None
 
-    def get_data_json(self):
-        """Get the PyBEL edge data dictionary this edge represents.
-
-        :rtype: dict
-        """
-        data = {
-            RELATION: self.relation,
-        }
-
-        annotations = self.get_annotations_json()
-        if annotations:
-            data[ANNOTATIONS] = annotations
-
-        if self.evidence:
-            data.update(self.evidence.to_json())
-
-        for prop in self.properties:  # FIXME this is also probably broken for translocations or mixed activity/degrad
-            if prop.side not in data:
-                data[prop.side] = prop.to_json()
-            else:
-                data[prop.side].update(prop.to_json())
-
-        return data
-
     def to_json(self, include_id=False):
         """Create a dictionary of one BEL Edge that can be used to create an edge in a :class:`BELGraph`.
 
@@ -925,11 +823,16 @@ class Edge(Base):
                  and edge data information.
         :rtype: dict
         """
+        source_dict = self.source.to_json()
+        source_dict['sha512'] = source_dict.sha512
+        target_dict = self.target.to_json()
+        target_dict['sha512'] = target_dict.sha512
+
         result = {
-            'source': self.source.to_json(),
-            'target': self.target.to_json(),
+            'source': source_dict,
+            'target': target_dict,
             'key': self.sha512,
-            'data': self.get_data_json(),
+            'data': json.loads(self.data),
         }
 
         if include_id:
@@ -942,7 +845,10 @@ class Edge(Base):
 
         :param pybel.BELGraph graph: A BEL graph
         """
-        u = graph.add_node_from_data(self.source.to_json())
-        v = graph.add_node_from_data(self.target.to_json())
+        u = self.source.as_bel()
+        v = self.target.as_bel()
 
-        graph.add_edge(u, v, key=self.sha512, **self.get_data_json())
+        if self.evidence:
+            return graph.add_qualified_edge(u, v, **json.loads(self.data))
+        else:
+            return graph.add_unqualified_edge(u, v, self.relation)
