@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 
-"""
-HGVS Variants
-~~~~~~~~~~~~~
+"""HGVS Variants.
+
 For example, the node :code:`p(HGNC:GSK3B, var(p.Gly123Arg))` is represented with the following:
 
 .. code::
@@ -23,7 +22,7 @@ For example, the node :code:`p(HGNC:GSK3B, var(p.Gly123Arg))` is represented wit
 .. seealso::
 
     - BEL 2.0 specification on `variants <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_variant_var>`_
-    - HVGS `conventions <http://www.hgvs.org/mutnomen/recs.html>`_
+    - HGVS `conventions <http://www.hgvs.org/mutnomen/recs.html>`_
     - PyBEL module :py:class:`pybel.parser.modifiers.get_hgvs_language`
 """
 
@@ -41,7 +40,7 @@ variant_characters = Word(alphanums + '._*=?>')
 
 
 def get_hgvs_language():
-    """
+    """Build a HGVS :class:`pyparsing.ParseElement`.
 
     :rtype: pyparsing.ParseElement
     """
