@@ -7,13 +7,17 @@ This module handles parsing BEL relations and validation of semantics.
 
 import itertools as itt
 import logging
+from typing import Dict, List, Mapping, Optional, Pattern, Set, Union
 
-from pyparsing import And, Group, Keyword, MatchFirst, Optional, StringEnd, Suppress, delimitedList, oneOf, replaceWith
+import pyparsing
+from pyparsing import (
+    And, Group, Keyword, MatchFirst, ParseResults, StringEnd, Suppress, delimitedList, oneOf, replaceWith,
+)
 
 from .baseparser import BaseParser
 from .exc import (
-    InvalidFunctionSemantic, MalformedTranslocationWarning, MissingAnnotationWarning, MissingCitationException,
-    MissingSupportWarning, NestedRelationWarning, RelabelWarning,
+    InvalidEntity, InvalidFunctionSemantic, MalformedTranslocationWarning, MissingAnnotationWarning,
+    MissingCitationException, MissingSupportWarning, NestedRelationWarning, RelabelWarning,
 )
 from .modifiers import (
     get_fragment_language, get_fusion_language, get_gene_modification_language, get_gene_substitution_language,
@@ -32,7 +36,7 @@ from ..constants import (
     POSITIVE_CORRELATION, PRODUCTS, PROTEIN, REACTANTS, REACTION, REGULATES, RELATION, RNA, SUBJECT, TARGET, TO_LOC,
     TRANSCRIBED_TO, TRANSLATED_TO, TRANSLOCATION, TWO_WAY_RELATIONS, VARIANTS, belns_encodings,
 )
-from ..dsl import cell_surface_expression, secretion
+from ..dsl import BaseEntity, cell_surface_expression, secretion
 from ..tokens import parse_result_to_dsl
 
 __all__ = [
@@ -216,47 +220,45 @@ partof_tag = Keyword(PART_OF)
 
 
 class BELParser(BaseParser):
-    """Build a parser backed by a given dictionary of namespaces"""
+    """Build a parser backed by a given dictionary of namespaces."""
 
-    def __init__(
-            self,
-            graph,
-            namespace_dict=None,
-            annotation_dict=None,
-            namespace_regex=None,
-            annotation_regex=None,
-            allow_naked_names=False,
-            allow_nested=False,
-            disallow_unqualified_translocations=False,
-            citation_clearing=True,
-            skip_validation=False,
-            autostreamline=True,
-            required_annotations=None
-    ):
+    def __init__(self,
+                 graph,
+                 namespace_to_term: Optional[Mapping[str, Mapping[str, str]]] = None,
+                 namespace_to_pattern: Optional[Mapping[str, Pattern]] = None,
+                 annotation_to_term: Optional[Mapping[str, Set[str]]] = None,
+                 annotation_to_pattern: Optional[Mapping[str, Pattern]] = None,
+                 annotation_to_local: Optional[Mapping[str, Set[str]]] = None,
+                 allow_naked_names: bool = False,
+                 allow_nested: bool = False,
+                 disallow_unqualified_translocations: bool = False,
+                 citation_clearing: bool = True,
+                 skip_validation: bool = False,
+                 autostreamline: bool = True,
+                 required_annotations: Optional[List[str]] = None,
+                 ) -> None:
         """Build a BEL parser.
 
         :param pybel.BELGraph graph: The BEL Graph to use to store the network
-        :param namespace_dict: A dictionary of {namespace: {name: encoding}}. Delegated to
+        :param namespace_to_term: A dictionary of {namespace: {name: encoding}}. Delegated to
          :class:`pybel.parser.parse_identifier.IdentifierParser`
-        :type namespace_dict: Optional[dict[str,dict[str,str]]]
-        :param annotation_dict: A dictionary of {annotation: set of values}. Delegated to
+        :param namespace_to_pattern: A dictionary of {namespace: regular expression strings}. Delegated to
+         :class:`pybel.parser.parse_identifier.IdentifierParser`
+        :param annotation_to_term: A dictionary of {annotation: set of values}. Delegated to
          :class:`pybel.parser.ControlParser`
-        :rype annotation_dict: Optional[dict[str,set[str]]]
-        :param namespace_regex: A dictionary of {namespace: regular expression strings}. Delegated to
-         :class:`pybel.parser.parse_identifier.IdentifierParser`
-        :type namespace_regex: Optional[dict[str,str]]
-        :param annotation_regex: A dictionary of {annotation: regular expression strings}. Delegated to
+        :param annotation_to_pattern: A dictionary of {annotation: regular expression strings}. Delegated to
          :class:`pybel.parser.ControlParser`
-        :type annotation_regex: Optional[dict[str,str]]
-        :param bool allow_naked_names: If true, turn off naked namespace failures. Delegated to
+        :param annotation_to_local: A dictionary of {annotation: set of values}. Delegated to
+         :class:`pybel.parser.ControlParser`
+        :param allow_naked_names: If true, turn off naked namespace failures. Delegated to
          :class:`pybel.parser.parse_identifier.IdentifierParser`
-        :param bool allow_nested: If true, turn off nested statement failures. Delegated to
+        :param allow_nested: If true, turn off nested statement failures. Delegated to
          :class:`pybel.parser.parse_identifier.IdentifierParser`
-        :param bool disallow_unqualified_translocations: If true, allow translocations without TO and FROM clauses.
-        :param bool citation_clearing: Should :code:`SET Citation` statements clear evidence and all annotations?
+        :param disallow_unqualified_translocations: If true, allow translocations without TO and FROM clauses.
+        :param citation_clearing: Should :code:`SET Citation` statements clear evidence and all annotations?
          Delegated to :class:`pybel.parser.ControlParser`
-        :param bool autostreamline: Should the parser be streamlined on instantiation?
-        :param Optional[list[str]] required_annotations: Optional list of required annotations
+        :param autostreamline: Should the parser be streamlined on instantiation?
+        :param required_annotations: Optional list of required annotations
         """
         self.graph = graph
 
@@ -274,18 +276,22 @@ class BELParser(BaseParser):
             )
         else:
             self.control_parser = ControlParser(
-                annotation_dict=annotation_dict,
-                annotation_regex=annotation_regex,
+                annotation_to_term=annotation_to_term,
+                annotation_to_pattern=annotation_to_pattern,
+                annotation_to_local=annotation_to_local,
                 citation_clearing=citation_clearing,
                 required_annotations=required_annotations,
             )
 
             self.identifier_parser = IdentifierParser(
                 allow_naked_names=allow_naked_names,
-                namespace_dict=namespace_dict,
-                namespace_regex=namespace_regex,
+                namespace_to_term=namespace_to_term,
+                namespace_to_pattern=namespace_to_pattern,
             )
 
+        self.control_parser.get_line_number = self.get_line_number
+        self.identifier_parser.get_line_number = self.get_line_number
+
         identifier = Group(self.identifier_parser.language)(IDENTIFIER)
         ungrouped_identifier = self.identifier_parser.language
 
@@ -296,7 +302,7 @@ class BELParser(BaseParser):
 
         #: `2.2.4 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#_cellular_location>`_
         self.location = get_location_language(self.identifier_parser.language)
-        opt_location = Optional(WCW + self.location)
+        opt_location = pyparsing.Optional(WCW + self.location)
 
         #: PyBEL BEL Specification variant
         self.gmod = get_gene_modification_language(self.identifier_parser.identifier_qualified)
@@ -311,7 +317,7 @@ class BELParser(BaseParser):
         #: `2.1.1 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#XcomplexA>`_
         self.general_abundance = general_abundance_tags + nest(ungrouped_identifier + opt_location)
 
-        self.gene_modified = ungrouped_identifier + Optional(
+        self.gene_modified = ungrouped_identifier + pyparsing.Optional(
             WCW + delimitedList(Group(variant | gsub | self.gmod))(VARIANTS))
 
         self.gene_fusion = Group(self.fusion)(FUSION)
@@ -324,13 +330,13 @@ class BELParser(BaseParser):
             self.gene_modified
         ]) + opt_location)
 
-        self.mirna_modified = ungrouped_identifier + Optional(
+        self.mirna_modified = ungrouped_identifier + pyparsing.Optional(
             WCW + delimitedList(Group(variant))(VARIANTS)) + opt_location
 
         #: `2.1.5 <http://openbel.org/language/version_2.0/bel_specification_version_2.0.html#XmicroRNAA>`_
         self.mirna = mirna_tag + nest(self.mirna_modified)
 
-        self.protein_modified = ungrouped_identifier + Optional(
+        self.protein_modified = ungrouped_identifier + pyparsing.Optional(
             WCW + delimitedList(Group(MatchFirst([self.pmod, variant, fragment, psub, trunc])))(
                 VARIANTS))
 
@@ -344,7 +350,7 @@ class BELParser(BaseParser):
             self.protein_modified,
         ]) + opt_location)
 
-        self.rna_modified = ungrouped_identifier + Optional(WCW + delimitedList(Group(variant))(VARIANTS))
+        self.rna_modified = ungrouped_identifier + pyparsing.Optional(WCW + delimitedList(Group(variant))(VARIANTS))
 
         self.rna_fusion = Group(self.fusion)(FUSION)
         self.rna_fusion_legacy = Group(get_legacy_fusion_langauge(identifier, 'r'))(FUSION)
@@ -409,7 +415,7 @@ class BELParser(BaseParser):
 
         self.activity_standard = activity_tag + nest(
             Group(self.simple_abundance)(TARGET) +
-            Optional(WCW + Group(self.molecular_activity)(EFFECT))
+            pyparsing.Optional(WCW + Group(self.molecular_activity)(EFFECT))
         )
 
         activity_legacy_tags = oneOf(language.activities)(MODIFIER)
@@ -603,122 +609,83 @@ class BELParser(BaseParser):
         super(BELParser, self).__init__(self.language, streamline=autostreamline)
 
     @property
-    def namespace_dict(self):
-        """The dictionary of {namespace: {name: encoding}} stored in the internal identifier parser
-
-        :rtype: dict[str,dict[str,str]]
-        """
-        return self.identifier_parser.namespace_dict
+    def _namespace_dict(self) -> Mapping[str, Mapping[str, str]]:
+        """Get the dictionary of {namespace: {name: encoding}} stored in the internal identifier parser."""
+        return self.identifier_parser.namespace_to_terms
 
     @property
-    def namespace_regex(self):
-        """The dictionary of {namespace keyword: compiled regular expression} stored the internal identifier parser
-
-        :rtype: dict[str,re]
-        """
-        return self.identifier_parser.namespace_regex_compiled
-
-    @property
-    def annotation_dict(self):
-        """A dictionary of annotations to their set of values
-
-        :rtype: dict[str,set[str]]
-        """
-        return self.control_parser.annotation_dict
-
-    @property
-    def annotation_regex(self):
-        """A dictionary of annotations defined by regular expressions {annotation keyword: string regular expression}
-
-        :rtype: dict[str,str]
-        """
-        return self.control_parser.annotation_regex
-
-    @property
-    def allow_naked_names(self):
-        """Should naked names be parsed, or should errors be thrown?
-
-        :rtype: bool
-        """
+    def _allow_naked_names(self) -> bool:
+        """Return if naked names should be parsed (``True``), or if errors should be thrown (``False``)."""
         return self.identifier_parser.allow_naked_names
 
-    def get_annotations(self):
-        """Get current annotations in this parser
-
-        :rtype: dict
-        """
+    def get_annotations(self) -> Dict:
+        """Get the current annotations in this parser."""
         return self.control_parser.get_annotations()
 
     def clear(self):
-        """Clears the graph and all control parser data (current citation, annotations, and statement group)"""
+        """Clear the graph and all control parser data (current citation, annotations, and statement group)."""
         self.graph.clear()
         self.control_parser.clear()
 
-    def handle_nested_relation(self, line, position, tokens):
-        """Handles nested statements. If :code:`allow_nested` is False, raises a warning.
+    def handle_nested_relation(self, line: str, position: int, tokens: ParseResults):
+        """Handle nested statements.
+
+        If :code:`allow_nested` is False, raises a ``NestedRelationWarning``.
 
-        :param str line: The line being parsed
-        :param int position: The position in the line being parsed
-        :param pyparsing.ParseResult tokens: The tokens from PyParsing
         :raises: NestedRelationWarning
         """
         if not self.allow_nested:
-            raise NestedRelationWarning(self.line_number, line, position)
+            raise NestedRelationWarning(self.get_line_number(), line, position)
 
         self._handle_relation_harness(line, position, {
             SUBJECT: tokens[SUBJECT],
             RELATION: tokens[RELATION],
-            OBJECT: tokens[OBJECT][SUBJECT]
+            OBJECT: tokens[OBJECT][SUBJECT],
         })
 
         self._handle_relation_harness(line, position, {
             SUBJECT: tokens[OBJECT][SUBJECT],
             RELATION: tokens[OBJECT][RELATION],
-            OBJECT: tokens[OBJECT][OBJECT]
+            OBJECT: tokens[OBJECT][OBJECT],
         })
         return tokens
 
-    def check_function_semantics(self, line, position, tokens):
-        """Raises an exception if the function used on the tokens is wrong
+    def check_function_semantics(self, line: str, position: int, tokens: ParseResults) -> ParseResults:
+        """Raise an exception if the function used on the tokens is wrong.
 
-        :param str line: The line being parsed
-        :param int position: The position in the line being parsed
-        :param pyparsing.ParseResult tokens: The tokens from PyParsing
         :raises: InvalidFunctionSemantic
         """
-        if self.namespace_dict is None or NAMESPACE not in tokens:
+        if not self._namespace_dict or NAMESPACE not in tokens:
             return tokens
 
         namespace, name = tokens[NAMESPACE], tokens[NAME]
 
-        if namespace in self.namespace_regex:
+        if namespace in self.identifier_parser.namespace_to_pattern:
             return tokens
 
-        if self.allow_naked_names and tokens[NAMESPACE] == DIRTY:  # Don't check dirty names in lenient mode
+        if self._allow_naked_names and tokens[NAMESPACE] == DIRTY:  # Don't check dirty names in lenient mode
             return tokens
 
         valid_functions = set(itt.chain.from_iterable(
-            belns_encodings[k]
-            for k in self.namespace_dict[namespace][name]
+            belns_encodings.get(k, set())
+            for k in self._namespace_dict[namespace][name]
         ))
 
+        if not valid_functions:
+            raise InvalidEntity(self.get_line_number(), line, position, namespace, name)
+
         if tokens[FUNCTION] not in valid_functions:
-            raise InvalidFunctionSemantic(self.line_number, line, position, tokens[FUNCTION], namespace, name,
+            raise InvalidFunctionSemantic(self.get_line_number(), line, position, tokens[FUNCTION], namespace, name,
                                           valid_functions)
 
         return tokens
 
-    def handle_term(self, line, position, tokens):
-        """Handle BEL terms (the subject and object of BEL relations).
-
-        :param str line: The line being parsed
-        :param int position: The position in the line being parsed
-        :param pyparsing.ParseResult tokens: The tokens from PyParsing
-        """
+    def handle_term(self, _, __, tokens: ParseResults) -> ParseResults:
+        """Handle BEL terms (the subject and object of BEL relations)."""
         self.ensure_node(tokens)
         return tokens
 
-    def _handle_list_helper(self, tokens, relation):
+    def _handle_list_helper(self, tokens: ParseResults, relation: str) -> ParseResults:
         """Provide the functionality for :meth:`handle_has_members` and :meth:`handle_has_components`."""
         parent_node_dsl = self.ensure_node(tokens[0])
 
@@ -728,27 +695,17 @@ class BELParser(BaseParser):
 
         return tokens
 
-    def handle_has_members(self, line, position, tokens):
-        """Handle list relations like ``p(X) hasMembers list(p(Y), p(Z), ...).``
-
-        :param str line: The line being parsed
-        :param int position: The position in the line being parsed
-        :param pyparsing.ParseResult tokens: The tokens from PyParsing
-        """
+    def handle_has_members(self, _, __, tokens: ParseResults) -> ParseResults:
+        """Handle list relations like ``p(X) hasMembers list(p(Y), p(Z), ...)``."""
         return self._handle_list_helper(tokens, HAS_MEMBER)
 
-    def handle_has_components(self, line, position, tokens):
-        """Handle list relations like ``p(X) hasComponents list(p(Y), p(Z), ...)``.
-
-        :param str line: The line being parsed
-        :param int position: The position in the line being parsed
-        :param pyparsing.ParseResult tokens: The tokens from PyParsing
-        """
+    def handle_has_components(self, _, __, tokens: ParseResults) -> ParseResults:
+        """Handle list relations like ``p(X) hasComponents list(p(Y), p(Z), ...)``."""
         return self._handle_list_helper(tokens, HAS_COMPONENT)
 
-    def _add_qualified_edge_helper(self, u, v, relation, annotations, subject_modifier, object_modifier):
+    def _add_qualified_edge_helper(self, u, v, relation, annotations, subject_modifier, object_modifier) -> str:
         """Add a qualified edge from the internal aspects of the parser."""
-        self.graph.add_qualified_edge(
+        return self.graph.add_qualified_edge(
             u,
             v,
             relation=relation,
@@ -757,12 +714,12 @@ class BELParser(BaseParser):
             annotations=annotations,
             subject_modifier=subject_modifier,
             object_modifier=object_modifier,
-            **{LINE: self.line_number}
+            **{LINE: self.get_line_number()}
         )
 
-    def _add_qualified_edge(self, u, v, relation, annotations, subject_modifier, object_modifier):
+    def _add_qualified_edge(self, u, v, relation, annotations, subject_modifier, object_modifier) -> str:
         """Add an edge, then adds the opposite direction edge if it should."""
-        self._add_qualified_edge_helper(
+        sha512 = self._add_qualified_edge_helper(
             u,
             v,
             relation=relation,
@@ -781,11 +738,10 @@ class BELParser(BaseParser):
                 subject_modifier=object_modifier,
             )
 
-    def _handle_relation(self, tokens):
-        """A policy in which all annotations are stored as sets, including single annotations.
+        return sha512
 
-        :param pyparsing.ParseResult tokens: The tokens from PyParsing
-        """
+    def _handle_relation(self, tokens: ParseResults) -> str:
+        """Handle a relation."""
         subject_node_dsl = self.ensure_node(tokens[SUBJECT])
         object_node_dsl = self.ensure_node(tokens[OBJECT])
 
@@ -806,7 +762,7 @@ class BELParser(BaseParser):
             for annotation_name, annotation_entry in self.control_parser.annotations.items()
         }
 
-        self._add_qualified_edge(
+        return self._add_qualified_edge(
             subject_node_dsl,
             object_node_dsl,
             relation=tokens[RELATION],
@@ -815,47 +771,35 @@ class BELParser(BaseParser):
             object_modifier=object_modifier,
         )
 
-    def _handle_relation_harness(self, line, position, tokens):
+    def _handle_relation_harness(self, line: str, position: int, tokens: Union[ParseResults, Dict]) -> ParseResults:
         """Handle BEL relations based on the policy specified on instantiation.
 
         Note: this can't be changed after instantiation!
-
-        :param str line: The line being parsed
-        :param int position: The position in the line being parsed
-        :param pyparsing.ParseResult tokens: The tokens from PyParsing
         """
         if not self.control_parser.citation:
-            raise MissingCitationException(self.line_number, line, position)
+            raise MissingCitationException(self.get_line_number(), line, position)
 
         if not self.control_parser.evidence:
-            raise MissingSupportWarning(self.line_number, line, position)
+            raise MissingSupportWarning(self.get_line_number(), line, position)
 
         missing_required_annotations = self.control_parser.get_missing_required_annotations()
         if missing_required_annotations:
-            raise MissingAnnotationWarning(self.line_number, line, position, missing_required_annotations)
+            raise MissingAnnotationWarning(self.get_line_number(), line, position, missing_required_annotations)
 
         self._handle_relation(tokens)
-
         return tokens
 
-    def handle_unqualified_relation(self, line, position, tokens):
-        """Handle unqualified relations.
-
-        :param str line: The line being parsed
-        :param int position: The position in the line being parsed
-        :param pyparsing.ParseResult tokens: The tokens from PyParsing
-        """
+    def handle_unqualified_relation(self, _, __, tokens: ParseResults) -> ParseResults:
+        """Handle unqualified relations."""
         subject_node_dsl = self.ensure_node(tokens[SUBJECT])
         object_node_dsl = self.ensure_node(tokens[OBJECT])
         rel = tokens[RELATION]
         self.graph.add_unqualified_edge(subject_node_dsl, object_node_dsl, rel)
+        return tokens
 
-    def handle_label_relation(self, line, position, tokens):
+    def handle_label_relation(self, line: str, position: int, tokens: ParseResults) -> ParseResults:
         """Handle statements like ``p(X) label "Label for X"``.
 
-        :param str line: The line being parsed
-        :param int position: The position in the line being parsed
-        :param pyparsing.ParseResult tokens: The tokens from PyParsing
         :raises: RelabelWarning
         """
         subject_node_dsl = self.ensure_node(tokens[SUBJECT])
@@ -863,7 +807,7 @@ class BELParser(BaseParser):
 
         if self.graph.has_node_description(subject_node_dsl):
             raise RelabelWarning(
-                line_number=self.line_number,
+                line_number=self.get_line_number(),
                 line=line,
                 position=position,
                 node=self.graph.node,
@@ -872,53 +816,34 @@ class BELParser(BaseParser):
             )
 
         self.graph.set_node_description(subject_node_dsl, description)
+        return tokens
 
-    def ensure_node(self, tokens):
-        """Turn parsed tokens into canonical node name and makes sure its in the graph.
-
-        :param pyparsing.ParseResult tokens: Tokens from PyParsing
-        :return: A pair of the PyBEL node tuple and the PyBEL node data dictionary
-        :rtype: BaseEntity
-        """
+    def ensure_node(self, tokens: ParseResults) -> BaseEntity:
+        """Turn parsed tokens into canonical node name and makes sure its in the graph."""
         if MODIFIER in tokens:
             return self.ensure_node(tokens[TARGET])
 
-        node_dsl = parse_result_to_dsl(tokens)
-        self.graph.add_node_from_data(node_dsl)
-        return node_dsl
+        node = parse_result_to_dsl(tokens)
+        self.graph.add_node_from_data(node)
+        return node
 
-    def handle_translocation_illegal(self, line, position, tokens):
-        """Handle a malformed translocation.
-
-        :param str line: The line being parsed
-        :param int position: The position in the line being parsed
-        :param pyparsing.ParseResult tokens: The tokens from PyParsing
-        """
-        raise MalformedTranslocationWarning(self.line_number, line, position, tokens)
+    def handle_translocation_illegal(self, line: str, position: int, tokens: ParseResults) -> None:
+        """Handle a malformed translocation."""
+        raise MalformedTranslocationWarning(self.get_line_number(), line, position, tokens)
 
 
 # HANDLERS
 
-def handle_molecular_activity_default(line, position, tokens):
-    """Handle a BEL 2.0 style molecular activity with BEL default names.
-
-    :param str line: The line being parsed
-    :param int position: The position in the line being parsed
-    :param pyparsing.ParseResult tokens: The tokens from PyParsing
-    """
+def handle_molecular_activity_default(_: str, __: int, tokens: ParseResults) -> ParseResults:
+    """Handle a BEL 2.0 style molecular activity with BEL default names."""
     upgraded = language.activity_labels[tokens[0]]
     tokens[NAMESPACE] = BEL_DEFAULT_NAMESPACE
     tokens[NAME] = upgraded
     return tokens
 
 
-def handle_activity_legacy(line, position, tokens):
-    """Handle BEL 1.0 activities.
-
-    :param str line: The line being parsed
-    :param int position: The position in the line being parsed
-    :param pyparsing.ParseResult tokens: The tokens from PyParsing
-    """
+def handle_activity_legacy(_: str, __: int, tokens: ParseResults) -> ParseResults:
+    """Handle BEL 1.0 activities."""
     legacy_cls = language.activity_labels[tokens[MODIFIER]]
     tokens[MODIFIER] = ACTIVITY
     tokens[EFFECT] = {
@@ -929,19 +854,14 @@ def handle_activity_legacy(line, position, tokens):
     return tokens
 
 
-def handle_legacy_tloc(line, position, tokens):
-    """Handles translocations that lack the ``fromLoc`` and ``toLoc`` entries
-
-    :param str line: The line being parsed
-    :param int position: The position in the line being parsed
-    :param pyparsing.ParseResult tokens: The tokens from PyParsing
-    """
-    log.log(5, 'legacy translocation statement: %s', line)
+def handle_legacy_tloc(line: str, position: int, tokens: ParseResults) -> ParseResults:
+    """Handle translocations that lack the ``fromLoc`` and ``toLoc`` entries."""
+    log.log(5, 'legacy translocation statement: %s [%d]', line, position)
     return tokens
 
 
 def modifier_po_to_dict(tokens):
-    """Get location, activity, and/or transformation information as a dictionary.
+    """Get the location, activity, and/or transformation information as a dictionary.
 
     :return: a dictionary describing the modifier
     :rtype: dict
