@@ -2,11 +2,11 @@
 
 """Functions for collapsing nodes."""
 
-from . import protein_rna_origins, collapse
-from .protein_rna_origins import *
+from . import collapse, protein_rna_origins
 from .collapse import *
+from .protein_rna_origins import *
 
 __all__ = (
-        protein_rna_origins.__all__ +
-        collapse.__all__
+    protein_rna_origins.__all__ +
+    collapse.__all__
 )
