@@ -10,7 +10,7 @@ __all__ = [
 ]
 
 
-def update_metadata(source, target):
+def update_metadata(source, target) -> None:
     """Update the namespace and annotation metadata in the target graph.
 
     :param pybel.BELGraph source:
@@ -21,20 +21,15 @@ def update_metadata(source, target):
 
     target.annotation_url.update(source.annotation_url)
     target.annotation_pattern.update(source.annotation_pattern)
-
     for keyword, values in source.annotation_list.items():
-        if keyword not in target.annotation_list:
-            target.annotation_list[keyword] = values
-        else:
-            for value in values:
-                target.annotation_list[keyword].add(value)
+        target.annotation_list[keyword].update(values)
 
 
-def update_node_helper(source, target):
+def update_node_helper(source: nx.Graph, target: nx.Graph) -> None:
     """Update the nodes' data dictionaries in the target graph from the source graph.
 
-    :param nx.Graph source: The universe of all knowledge
-    :param nx.Graph target: The target BEL graph
+    :param source: The universe of all knowledge
+    :param target: The target BEL graph
     """
     for node in target:
         if node in source:
