@@ -15,13 +15,16 @@ from pybel.constants import (
 from pybel.dsl import BaseEntity, complex_abundance, pathology, protein
 from pybel.dsl.namespaces import hgnc
 from pybel.parser.exc import (
-    BELSyntaxError, IllegalAnnotationValueWarning, InvalidCitationLengthException, InvalidCitationType,
-    InvalidFunctionSemantic, InvalidPubMedIdentifierWarning, MalformedTranslocationWarning, MissingAnnotationKeyWarning,
-    MissingAnnotationRegexWarning, MissingCitationException, MissingMetadataException, MissingNamespaceNameWarning,
-    MissingNamespaceRegexWarning, MissingSupportWarning, NakedNameWarning, NestedRelationWarning,
-    PlaceholderAminoAcidWarning, UndefinedAnnotationWarning, UndefinedNamespaceWarning, VersionFormatWarning,
+    BELParserWarning, BELSyntaxError, IllegalAnnotationValueWarning, InvalidCitationLengthException,
+    InvalidCitationType, InvalidFunctionSemantic, InvalidPubMedIdentifierWarning, MalformedTranslocationWarning,
+    MissingAnnotationKeyWarning, MissingAnnotationRegexWarning, MissingCitationException, MissingMetadataException,
+    MissingNamespaceNameWarning, MissingNamespaceRegexWarning, MissingSupportWarning, NakedNameWarning,
+    NestedRelationWarning, PlaceholderAminoAcidWarning, UndefinedAnnotationWarning, UndefinedNamespaceWarning,
+    VersionFormatWarning,
 )
 from pybel.parser.parse_bel import BELParser
+from pybel.parser.parse_control import ControlParser
+from pybel.testing.constants import test_bel_thorough
 from pybel.utils import subdict_matches
 from tests.constant_helper import (
     BEL_THOROUGH_EDGES, BEL_THOROUGH_NODES, citation_1, evidence_1, expected_test_simple_metadata,
@@ -50,25 +53,14 @@ fadd = hgnc(name='FADD')
 casp8 = hgnc(name='CASP8')
 
 
-def update_provenance(control_parser):
-    """Put a default evidence and citation in a BEL parser.
-    
-    :param pybel.parser.parse_control.ControlParser control_parser:
-    """
+def update_provenance(control_parser: ControlParser) -> None:
+    """Put a default evidence and citation in a BEL parser."""
     control_parser.citation.update(test_citation_dict)
     control_parser.evidence = test_evidence_text
 
 
-def assert_has_node(self, node, graph, **kwargs):
-    """Check if a node with the given properties is contained within a graph.
-
-    :param self: A Test Case
-    :type self: unittest.TestCase
-    :param node: 
-    :param graph:
-    :type graph: BELGraph
-    :param kwargs:
-    """
+def assert_has_node(self: unittest.TestCase, node: BaseEntity, graph: BELGraph, **kwargs):
+    """Check if a node with the given properties is contained within a graph."""
     self.assertIsInstance(node, BaseEntity)
 
     self.assertIn(
@@ -116,16 +108,8 @@ def any_subdict_matches(dict_of_dicts, query_dict):
     )
 
 
-def assert_has_edge(self, u, v, graph, permissive=True, **kwargs):
-    """A helper function for checking if an edge with the given properties is contained within a graph
-
-    :param unittest.TestCase self: A TestCase
-    :param u: source node
-    :type u: BaseEntity or tuple
-    :param v: target node
-    :type v: BaseEntity or tuple
-    :param BELGraph graph: underlying graph
-    """
+def assert_has_edge(self: unittest.TestCase, u: BaseEntity, v: BaseEntity, graph: BELGraph, permissive=True, **kwargs):
+    """A helper function for checking if an edge with the given properties is contained within a graph."""
     self.assertIsInstance(u, BaseEntity)
     self.assertIsInstance(v, BaseEntity)
 
@@ -157,23 +141,12 @@ def assert_has_edge(self, u, v, graph, permissive=True, **kwargs):
 class TestGraphMixin(unittest.TestCase):
     """A test case with additional functions for testing graphs."""
 
-    def assert_has_node(self, g, n, **kwargs):
-        """Help assert node membership.
-        
-        :param g: Graph 
-        :param n: Node
-        :param kwargs: 
-        """
+    def assert_has_node(self, g: BELGraph, n: BaseEntity, **kwargs):
+        """Help assert node membership."""
         assert_has_node(self, n, g, **kwargs)
 
-    def assert_has_edge(self, g, u, v, **kwargs):
-        """Help assert edge membership.
-        
-        :param g: Graph
-        :param u: Source node
-        :param v: Target node
-        :param kwargs: 
-        """
+    def assert_has_edge(self, g: BELGraph, u: BaseEntity, v: BaseEntity, **kwargs):
+        """Help assert edge membership."""
         assert_has_edge(self, u, v, g, **kwargs)
 
 
@@ -194,21 +167,12 @@ class TestTokenParserBase(unittest.TestCase):
         """Clear the parser at the beginning of each test."""
         self.parser.clear()
 
-    def assert_has_node(self, member, **kwargs):
-        """Assert that this test case's graph has the given node.
-
-        :type member: tuple or BaseEntity
-        """
+    def assert_has_node(self, member: BaseEntity, **kwargs):
+        """Assert that this test case's graph has the given node."""
         assert_has_node(self, member, self.graph, **kwargs)
 
-    def assert_has_edge(self, u, v, **kwargs):
-        """Assert that this test case's graph has the given edge.
-
-        :param u: source node
-        :type u: BaseEntity or tuple
-        :param v: target node
-        :type v: BaseEntity or tuple
-        """
+    def assert_has_edge(self, u: BaseEntity, v: BaseEntity, **kwargs):
+        """Assert that this test case's graph has the given edge."""
         assert_has_edge(self, u, v, self.graph, **kwargs)
 
     def add_default_provenance(self):
@@ -216,13 +180,8 @@ class TestTokenParserBase(unittest.TestCase):
         update_provenance(self.parser.control_parser)
 
 
-def help_check_hgnc(test_case, namespace_dict):
-    """Assert that the namespace dictionary is correct.
-
-    :param unittest.TestCase test_case:
-    :param namespace_dict:
-    :return:
-    """
+def help_check_hgnc(test_case: unittest.TestCase, namespace_dict) -> None:
+    """Assert that the namespace dictionary is correct."""
     test_case.assertIn(HGNC_KEYWORD, namespace_dict)
 
     test_case.assertIn('MHS2', namespace_dict[HGNC_KEYWORD])
@@ -238,12 +197,8 @@ def help_check_hgnc(test_case, namespace_dict):
 class BelReconstitutionMixin(TestGraphMixin):
     """A test case that has checks for properly loading several BEL Scripts."""
 
-    def bel_simple_reconstituted(self, graph, check_metadata=True):
-        """Check that test_bel.bel was loaded properly.
-
-        :param BELGraph graph: A BEL grpah
-        :param bool check_metadata: Check the graph's document section is correct
-        """
+    def bel_simple_reconstituted(self, graph: BELGraph, check_metadata: bool = True):
+        """Check that test_bel.bel was loaded properly."""
         self.assertIsNotNone(graph)
         self.assertIsInstance(graph, BELGraph)
 
@@ -333,16 +288,23 @@ class BelReconstitutionMixin(TestGraphMixin):
             EVIDENCE: evidence_3,
         })
 
-    def bel_thorough_reconstituted(self, graph, check_metadata=True, check_warnings=True, check_provenance=True,
-                                   check_citation_name=True):
+    def bel_thorough_reconstituted(self,
+                                   graph: BELGraph,
+                                   check_metadata: bool = True,
+                                   check_warnings: bool = True,
+                                   check_provenance: bool = True,
+                                   check_citation_name: bool = True,
+                                   check_path: bool = True,
+                                   ):
         """Check that thorough.bel was loaded properly.
 
-        :param BELGraph graph: A BEL graph
-        :param bool check_metadata: Check the graph's document section is correct
-        :param bool check_warnings: Check the graph produced the expected warnings
-        :param bool check_provenance: Check the graph's definition section is correct
-        :param bool check_citation_name: Check that the names in the citations get reconstituted. This isn't strictly
+        :param graph: A BEL graph
+        :param check_metadata: Check the graph's document section is correct
+        :param check_warnings: Check the graph produced the expected warnings
+        :param check_provenance: Check the graph's definition section is correct
+        :param check_citation_name: Check that the names in the citations get reconstituted. This isn't strictly
                                          necessary since this data can be looked up
+        :param check_path: Check the graph contains provenance for its original file
         """
         self.assertIsNotNone(graph)
         self.assertIsInstance(graph, BELGraph)
@@ -357,10 +319,15 @@ class BelReconstitutionMixin(TestGraphMixin):
             self.assertEqual(expected_test_thorough_metadata[METADATA_VERSION], graph.version)
             self.assertEqual(expected_test_thorough_metadata[METADATA_DESCRIPTION], graph.description)
 
+        if check_path:
+            self.assertEqual(test_bel_thorough, graph.path)
+
         if check_provenance:
             self.assertEqual({'CHEBI', 'HGNC', 'GOBP', 'GOCC', 'MESHD', 'TESTNS2'}, set(graph.namespace_url))
             self.assertEqual({'dbSNP'}, set(graph.namespace_pattern))
-            self.assertEqual({'TESTAN1', 'TESTAN2'}, set(graph.annotation_list))
+            self.assertIn('TESTAN1', graph.annotation_list)
+            self.assertIn('TESTAN2', graph.annotation_list)
+            self.assertEqual(2, len(graph.annotation_list), msg='Wrong number of locally defined annotations')
             self.assertEqual({'TestRegex'}, set(graph.annotation_pattern))
 
         for node in graph:
@@ -380,13 +347,8 @@ class BelReconstitutionMixin(TestGraphMixin):
 
             assert_has_edge(self, u, v, graph, permissive=True, **data)
 
-    def bel_slushy_reconstituted(self, graph, check_metadata=True, check_warnings=True):
-        """Check that slushy.bel was loaded properly.
-        
-        :param BELGraph graph: A BEL graph
-        :param bool check_metadata: Check the graph's document section is correct
-        :param bool check_warnings: Check the graph produced the expected warnings
-        """
+    def bel_slushy_reconstituted(self, graph: BELGraph, check_metadata: bool = True, check_warnings: bool = True):
+        """Check that slushy.bel was loaded properly."""
         self.assertIsNotNone(graph)
         self.assertIsInstance(graph, BELGraph)
 
@@ -435,18 +397,27 @@ class BelReconstitutionMixin(TestGraphMixin):
                 (98, BELSyntaxError),
             ]
 
-            for (el, ew), (l, _, w, _) in zip(expected_warnings, graph.warnings):
-                self.assertEqual(el, l, msg="Expected different error on line {}. Check line {}".format(el, l))
-                self.assertIsInstance(w, ew, msg='Line: {}'.format(el))
+            for warning_tuple in graph.warnings:
+                self.assertEqual(3, len(warning_tuple), msg='Warning tuple is wrong size: {}'.format(warning_tuple))
+
+            for (el, ew), (_, exc, _) in zip(expected_warnings, graph.warnings):
+                self.assertIsInstance(exc, BELParserWarning)
+                self.assertIsInstance(exc.line, str)
+                self.assertIsInstance(exc.line_number, int)
+                self.assertIsInstance(exc.position, int)
+                self.assertEqual(el, exc.line_number, msg="Expected {} on line {} but got {} on line {}: {}".format(
+                    ew, el, exc.__class__, exc.line_number, exc
+                ))
+                self.assertIsInstance(exc, ew, msg='Line: {}'.format(el))
 
         for node in graph:
             self.assertIsInstance(node, BaseEntity)
 
-        self.assertIn(akt1, graph)
-        self.assertIn(egfr, graph)
+        self.assertIn(akt1, graph, msg='AKT1 not in graph')
+        self.assertIn(egfr, graph, msg='EGFR not in graph')
 
-        self.assertEqual(2, graph.number_of_nodes())
-        self.assertEqual(1, graph.number_of_edges())
+        self.assertEqual(2, graph.number_of_nodes(), msg='Wrong number of nodes retrieved from slushy.bel')
+        self.assertEqual(1, graph.number_of_edges(), msg='Wrong nunber of edges retrieved from slushy.bel')
 
         assert_has_edge(self, akt1, egfr, graph, **{
             RELATION: INCREASES,
@@ -454,11 +425,8 @@ class BelReconstitutionMixin(TestGraphMixin):
             EVIDENCE: evidence_1,
         })
 
-    def bel_isolated_reconstituted(self, graph):
-        """Run the isolated node test.
-
-        :type graph: BELGraph
-        """
+    def bel_isolated_reconstituted(self, graph: BELGraph):
+        """Run the isolated node test."""
         self.assertIsNotNone(graph)
         self.assertIsInstance(graph, BELGraph)
 
