@@ -479,15 +479,13 @@ class TestRelations(TestTokenParserBase):
         self.assert_has_edge(sub, obj, relation=expected_dict[RELATION])
 
     def test_nested_failure(self):
-        """
-        3.1 \
-        Test nested statement"""
+        """Test nested statement (3.1)."""
         statement = 'p(HGNC:CAT) -| (a(CHEBI:"hydrogen peroxide") -> bp(GO:"apoptotic process"))'
         with self.assertRaises(NestedRelationWarning):
             self.parser.relation.parseString(statement)
 
     def test_nested_lenient(self):
-        """ 3.1 \ Test nested statement"""
+        """Test nested statement (3.1)."""
         statement = 'p(HGNC:CAT) -| (a(CHEBI:"hydrogen peroxide") -> bp(GO:"apoptotic process"))'
         self.parser.allow_nested = True
 
@@ -910,7 +908,7 @@ class TestRelations(TestTokenParserBase):
         statement = 'rxn(reactants(a(CHEBI:"(S)-3-hydroxy-3-methylglutaryl-CoA"),a(CHEBI:NADPH), \
                     a(CHEBI:hydron)),products(a(CHEBI:mevalonate), a(CHEBI:"CoA-SH"), a(CHEBI:"NADP(+)"))) \
                     hasReactant a(CHEBI:"(S)-3-hydroxy-3-methylglutaryl-CoA")'
-        result = self.parser.relation.parseString(statement)
+        self.parser.relation.parseString(statement)
 
         sub_reactant_1 = abundance('CHEBI', '(S)-3-hydroxy-3-methylglutaryl-CoA')
         sub_reactant_2 = abundance('CHEBI', 'NADPH')
@@ -944,7 +942,7 @@ class TestCustom(unittest.TestCase):
     def setUp(self):
         graph = BELGraph()
 
-        namespace_dict = {
+        namespace_to_term = {
             'HGNC': {
                 'AKT1': 'GRP',
                 'YFG': 'GRP'
@@ -954,7 +952,7 @@ class TestCustom(unittest.TestCase):
             }
         }
 
-        self.parser = BELParser(graph, namespace_dict=namespace_dict, autostreamline=False)
+        self.parser = BELParser(graph, namespace_to_term=namespace_to_term, autostreamline=False)
 
     def test_tloc_undefined_namespace(self):
         s = 'tloc(p(HGNC:AKT1), fromLoc(MESHCS:nucleus), toLoc(MISSING:"undefined"))'
